@@ -92,13 +92,8 @@ def list_plugins(args):
     print(colorize(f"Listing plugins for repository '{args.repo}' on machine '{args.machine}'...", 'HEADER'))
     
     conn = RepositoryConnection(args.team, args.machine, args.repo); conn.connect()
-    
-    original_host_entry = conn.connection_info.get('host_entry') if args.dev else None
-    if args.dev: conn.connection_info['host_entry'] = None
-    
+
     with conn.ssh_context() as ssh_conn:
-        if args.dev and original_host_entry is not None: 
-            conn.connection_info['host_entry'] = original_host_entry
         universal_user = conn.connection_info.get('universal_user', 'rediacc')
         
         # Use the new plugin_socket_dir for listing sockets
@@ -179,24 +174,20 @@ def connect_plugin(args):
             error_exit("No available ports in range 7111-9111")
     
     conn = RepositoryConnection(args.team, args.machine, args.repo); conn.connect()
-    
-    original_host_entry = conn.connection_info.get('host_entry') if args.dev else None
-    if args.dev: conn.connection_info['host_entry'] = None
-    
+
     # Get SSH key for tunnel connection
     ssh_key = get_ssh_key_from_vault(args.team)
     if not ssh_key:
         error_exit(f"SSH key not found for team '{args.team}'")
-    
+
     # Use SSHTunnelConnection for persistent tunnels
-    host_entry = None if args.dev else conn.connection_info.get('host_entry')
+    host_entry = conn.connection_info.get('host_entry')
+    if not host_entry:
+        error_exit("Security Error: No host key found in machine vault. Contact your administrator to add the host key.")
     ssh_tunnel_conn = SSHTunnelConnection(ssh_key, host_entry)
     ssh_tunnel_conn.__enter__()  # Setup connection
     ssh_tunnel_conn.disable_auto_cleanup()  # Prevent auto cleanup for persistent tunnel
     
-    if args.dev and original_host_entry is not None: 
-        conn.connection_info['host_entry'] = original_host_entry
-    
     try:
         # Verify plugin socket exists
         universal_user = conn.connection_info.get('universal_user', 'rediacc')
@@ -404,6 +395,7 @@ def main():
     initialize_telemetry()
 
     parser = argparse.ArgumentParser(
+        prog='rediacc plugin',
         description='Rediacc CLI Plugin - SSH tunnel management for repository plugins',
         formatter_class=argparse.RawDescriptionHelpFormatter,
         epilog="""
@@ -430,16 +422,17 @@ Plugin Access:
   The local port forwards to the plugin's Unix socket on the remote repository.
 """
     )
-    
-    parser.add_argument('--version', action='version', 
-                       version=f'Rediacc CLI Plugin v{__version__}' if __version__ != 'dev' else 'Rediacc CLI Plugin Development')
-    
+
+    # Note: --version is only available at root level (rediacc --version)
+
+    # Add verbose to main parser (applies to all subcommands)
+    add_common_arguments(parser, include_args=['verbose'])
+
     subparsers = parser.add_subparsers(dest='command', help='Commands')
     
     # List command
     list_parser = subparsers.add_parser('list', help='List available plugins in a repository')
     add_common_arguments(list_parser, include_args=['token', 'team', 'machine', 'repo'])
-    list_parser.add_argument('--dev', action='store_true', help='Development mode - relaxes SSH host key checking')
     list_parser.set_defaults(func=list_plugins)
     
     # Connect command
@@ -447,7 +440,6 @@ Plugin Access:
     add_common_arguments(connect_parser, include_args=['token', 'team', 'machine', 'repo'])
     connect_parser.add_argument('--plugin', required=True, help='Plugin name (e.g., browser, terminal)')
     connect_parser.add_argument('--port', type=int, help='Local port to use (auto-assigned if not specified)')
-    connect_parser.add_argument('--dev', action='store_true', help='Development mode - relaxes SSH host key checking')
     connect_parser.set_defaults(func=connect_plugin)
     
     # Disconnect command
