@@ -8,6 +8,7 @@ import subprocess
 import sys
 import os
 import json
+import shlex
 from pathlib import Path
 
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))
@@ -21,13 +22,14 @@ from cli.core.shared import (
 
 from cli.core.config import setup_logging, get_logger
 from cli.core.telemetry import track_command, initialize_telemetry, shutdown_telemetry
+from cli.core.env_bootstrap import compose_sudo_env_command
+from cli.config import TERM_CONFIG_FILE
 
 # Load configuration
 def load_config():
     """Load configuration from JSON file"""
-    config_path = Path(__file__).parent.parent.parent / 'config' / 'rediacc-term-config.json'
-    try: 
-        with open(config_path, 'r', encoding='utf-8') as f:
+    try:
+        with open(TERM_CONFIG_FILE, 'r', encoding='utf-8') as f:
             return json.load(f)
     except (FileNotFoundError, json.JSONDecodeError) as e:
         print(f"Warning: Could not load config file: {e}")
@@ -63,22 +65,26 @@ def get_config_value(*keys, default=''):
 
 def connect_to_machine(args):
     print_message('connecting_machine', 'HEADER', machine=args.machine)
-    
+
     from cli.core.shared import get_machine_info_with_team, get_machine_connection_info, validate_machine_accessibility, handle_ssh_exit_code
-    
+
     print(MESSAGES.get('fetching_info', 'Fetching machine information...'))
     machine_info = get_machine_info_with_team(args.team, args.machine)
     connection_info = get_machine_connection_info(machine_info)
-    validate_machine_accessibility(args.machine, args.team, connection_info['ip'])
-    
+    port = connection_info.get('port', 22)
+    validate_machine_accessibility(args.machine, args.team, connection_info['ip'], port)
+
     print(MESSAGES.get('retrieving_ssh_key', 'Retrieving SSH key...'))
     ssh_key = get_ssh_key_from_vault(args.team)
-    if not ssh_key: 
+    if not ssh_key:
         error_exit(MESSAGES.get('ssh_key_not_found', 'SSH key not found').format(team=args.team))
-    
-    host_entry = None if args.dev else connection_info.get('host_entry')
-    
-    with SSHConnection(ssh_key, host_entry) as ssh_conn:
+
+    host_entry = connection_info.get('host_entry')
+
+    if not host_entry:
+        error_exit("Security Error: No host key found in machine vault. Contact your administrator to add the host key.")
+
+    with SSHConnection(ssh_key, host_entry, port) as ssh_conn:
         if ssh_conn.is_using_agent:
             print_message('ssh_agent_setup', pid=ssh_conn.agent_pid)
         
@@ -98,7 +104,7 @@ def connect_to_machine(args):
             welcome_lines = [cmd.format(**format_vars) for cmd in commands]
             ssh_cmd.append(f"sudo -u {universal_user} bash -c '{' && '.join(welcome_lines)}'")
             print_message('opening_terminal'); print_message('exit_instruction', 'YELLOW')
-        
+
         result = subprocess.run(ssh_cmd)
         handle_ssh_exit_code(result.returncode, "machine")
 
@@ -111,7 +117,8 @@ def connect_to_terminal(args):
     logger = get_logger(__name__)
 
     conn = RepositoryConnection(args.team, args.machine, args.repo); conn.connect()
-    validate_machine_accessibility(args.machine, args.team, conn.connection_info['ip'], args.repo)
+    port = conn.connection_info.get('port', 22)
+    validate_machine_accessibility(args.machine, args.team, conn.connection_info['ip'], port, args.repo)
 
     # DEBUG: Log terminal connection details
     logger.debug(f"[connect_to_terminal] Terminal connection details:")
@@ -121,36 +128,43 @@ def connect_to_terminal(args):
     logger.debug(f"  - repo_guid: {conn.repo_guid}")
     logger.debug(f"  - mount_path: {conn.repo_paths['mount_path']}")
 
-    original_host_entry = conn.connection_info.get('host_entry') if args.dev else None
-    if args.dev: conn.connection_info['host_entry'] = None
     ssh_key = get_ssh_key_from_vault(args.team)
     if not ssh_key:
         error_exit(MESSAGES.get('ssh_key_not_found', 'SSH key not found').format(team=args.team))
 
-    host_entry = None if args.dev else conn.connection_info.get('host_entry')
+    host_entry = conn.connection_info.get('host_entry')
 
-    with SSHConnection(ssh_key, host_entry) as ssh_conn:
+    if not host_entry:
+        error_exit("Security Error: No host key found in repository machine vault. Contact your administrator to add the host key.")
+
+    with SSHConnection(ssh_key, host_entry, port) as ssh_conn:
         if ssh_conn.is_using_agent:
             print_message('ssh_agent_setup', pid=ssh_conn.agent_pid)
+        # Get environment variables using shared module (DRY principle)
+        from cli.core.repository_env import get_repository_environment
+
+        env_vars = get_repository_environment(args.team, args.machine, args.repo,
+                                              connection_info=conn.connection_info,
+                                              repo_paths=conn.repo_paths)
 
-        if args.dev and original_host_entry is not None:
-            conn.connection_info['host_entry'] = original_host_entry
-        repo_paths = conn.repo_paths
-        docker_socket = repo_paths['docker_socket']
-        docker_host = f"unix://{docker_socket}"
-        repo_mount_path = repo_paths['mount_path']
-        
-        env_template = CONFIG.get('environment_exports', {})
-        env_format_vars = {'repo_mount_path': repo_mount_path, 'docker_host': docker_host, 'docker_folder': repo_paths['docker_folder'], 'docker_socket': docker_socket, 'docker_data': repo_paths['docker_data'], 'docker_exec': repo_paths['docker_exec']}
-        env_exports = '\n'.join(f'export {key}=\'{value.format(**env_format_vars)}\'' for key, value in env_template.items()) + '\n'
-        env_exports += f'export REDIACC_REPO="{args.repo}"\n'
-        env_exports += f'export REDIACC_TEAM="{args.team}"\n'
-        env_exports += f'export REDIACC_MACHINE="{args.machine}"\n'
-        
         cd_logic = get_config_value('cd_logic', 'basic')
         
-        if args.command: ssh_env_setup = env_exports + cd_logic
+        universal_user = conn.connection_info.get('universal_user', 'rediacc')
+        ssh_cmd = ['ssh', '-tt', *ssh_conn.ssh_opts.split(), conn.ssh_destination]
+
+        if args.command:
+            # Simplified approach: execute command in a basic environment without complex setup
+            print_message('executing_command', command=args.command)
+            sudo_command = compose_sudo_env_command(
+                universal_user,
+                env_vars,
+                [cd_logic, args.command],
+                preserve_home=False,
+            )
+            ssh_cmd.append(sudo_command)
         else:
+            # For interactive terminal, use the existing complex setup that works
+            print_message('opening_terminal'); print_message('exit_instruction', 'YELLOW')
             extended_cd_logic = get_config_value('cd_logic', 'extended')
             bash_funcs = CONFIG.get('bash_functions', {})
             format_vars = {
@@ -165,25 +179,25 @@ def connect_to_terminal(args):
             functions = '\n\n'.join(bash_funcs.values())
             exports = 'export -f enter_container\nexport -f logs\nexport -f status'
 
-            ssh_env_setup = f"""{env_exports}{extended_cd_logic}\n\n{functions}\n\n{exports}\n\n{chr(10).join(welcome_lines)}\n\nexport PS1='{ps1_prompt}'\n"""
-        
-        universal_user = conn.connection_info.get('universal_user', 'rediacc')
-        ssh_cmd = ['ssh', '-tt', *ssh_conn.ssh_opts.split(), conn.ssh_destination]
-        import shlex
+            script_sections = [extended_cd_logic]
+            if functions:
+                script_sections.extend(['', functions])
+            if exports:
+                script_sections.extend(['', exports])
+            if welcome_lines:
+                script_sections.append('')
+                script_sections.extend(welcome_lines)
+            script_sections.append('')
+            script_sections.append(f"export PS1='{ps1_prompt}'")
+            script_sections.append('exec bash')
 
-        if args.command:
-            # Simplified approach: execute command in a basic environment without complex setup
-            print_message('executing_command', command=args.command)
-            # Set up minimal environment and execute the command
-            minimal_env = env_exports + get_config_value('cd_logic', 'basic') + '\n'
-            script_content = minimal_env + args.command
-            ssh_cmd.extend(['sudo', '-u', universal_user, 'bash', '-c', script_content])
-        else:
-            # For interactive terminal, use the existing complex setup that works
-            print_message('opening_terminal'); print_message('exit_instruction', 'YELLOW')
-            full_command = ssh_env_setup + "exec bash"
-            escaped_env = full_command.replace("'", "'\"'\"'")
-            ssh_cmd.append(f"sudo -u {universal_user} bash -c '{escaped_env}'")
+            sudo_command = compose_sudo_env_command(
+                universal_user,
+                env_vars,
+                script_sections,
+                preserve_home=False,
+            )
+            ssh_cmd.append(sudo_command)
         result = subprocess.run(ssh_cmd)
         handle_ssh_exit_code(result.returncode, "repository terminal")
 
@@ -194,48 +208,53 @@ def connect_to_container(args):
     from cli.core.shared import validate_machine_accessibility, handle_ssh_exit_code
 
     conn = RepositoryConnection(args.team, args.machine, args.repo); conn.connect()
-    validate_machine_accessibility(args.machine, args.team, conn.connection_info['ip'], args.repo)
+    port = conn.connection_info.get('port', 22)
+    validate_machine_accessibility(args.machine, args.team, conn.connection_info['ip'], port, args.repo)
 
-    original_host_entry = conn.connection_info.get('host_entry') if args.dev else None
-    if args.dev: conn.connection_info['host_entry'] = None
     ssh_key = get_ssh_key_from_vault(args.team)
     if not ssh_key:
         error_exit(MESSAGES.get('ssh_key_not_found', 'SSH key not found').format(team=args.team))
 
-    host_entry = None if args.dev else conn.connection_info.get('host_entry')
+    host_entry = conn.connection_info.get('host_entry')
 
-    with SSHConnection(ssh_key, host_entry) as ssh_conn:
+    if not host_entry:
+        error_exit("Security Error: No host key found in repository machine vault. Contact your administrator to add the host key.")
+
+    with SSHConnection(ssh_key, host_entry, port) as ssh_conn:
         if ssh_conn.is_using_agent:
             print_message('ssh_agent_setup', pid=ssh_conn.agent_pid)
+        # Get environment variables using shared module (DRY principle)
+        from cli.core.repository_env import get_repository_environment
 
-        if args.dev and original_host_entry is not None:
-            conn.connection_info['host_entry'] = original_host_entry
-        repo_paths = conn.repo_paths
-        docker_socket = repo_paths['docker_socket']
-        docker_host = f"unix://{docker_socket}"
-
-        env_template = CONFIG.get('environment_exports', {})
-        env_format_vars = {'repo_mount_path': repo_paths['mount_path'], 'docker_host': docker_host, 'docker_folder': repo_paths['docker_folder'], 'docker_socket': docker_socket, 'docker_data': repo_paths['docker_data'], 'docker_exec': repo_paths['docker_exec']}
-        env_exports = '\n'.join(f'export {key}=\'{value.format(**env_format_vars)}\'' for key, value in env_template.items()) + '\n'
+        env_vars = get_repository_environment(args.team, args.machine, args.repo,
+                                              connection_info=conn.connection_info,
+                                              repo_paths=conn.repo_paths)
 
         universal_user = conn.connection_info.get('universal_user', 'rediacc')
         ssh_cmd = ['ssh', '-tt', *ssh_conn.ssh_opts.split(), conn.ssh_destination]
 
-        # Set up the environment first (same as repository terminal)
-        ssh_env_setup = env_exports
-
         if args.command:
             # Execute command inside container
-            ssh_env_setup += f"docker exec -it {args.container} bash -c '{args.command}'"
+            container_command = (
+                f"docker exec -it {args.container} bash -c {shlex.quote(args.command)}"
+            )
+            script_sections = [container_command]
             print_message('executing_container_command', container=args.container, command=args.command)
         else:
             # Interactive container access - use the same pattern as existing enter_container function
             print_message('entering_container', container=args.container)
             print_message('exit_instruction', 'YELLOW')
-            ssh_env_setup += f"docker exec -it {args.container} bash || docker exec -it {args.container} sh"
+            script_sections = [
+                f"docker exec -it {args.container} bash || docker exec -it {args.container} sh"
+            ]
 
-        escaped_env = ssh_env_setup.replace("'", "'\"'\"'")
-        ssh_cmd.append(f"sudo -u {universal_user} bash -c '{escaped_env}'")
+        sudo_command = compose_sudo_env_command(
+            universal_user,
+            env_vars,
+            script_sections,
+            preserve_home=False,
+        )
+        ssh_cmd.append(sudo_command)
         result = subprocess.run(ssh_cmd)
         handle_ssh_exit_code(result.returncode, "container terminal")
 
@@ -267,21 +286,20 @@ def main():
     epilog_text = '\n\n'.join(sections)
     
     parser = argparse.ArgumentParser(
+        prog='rediacc term',
         description=help_config.get('description', 'Rediacc CLI Terminal'),
         formatter_class=argparse.RawDescriptionHelpFormatter,
         epilog=epilog_text
     )
-    parser.add_argument('--version', action='version', 
-                       version=f'Rediacc CLI Term v{__version__}' if __version__ != 'dev' else 'Rediacc CLI Term Development')
-    # Add common arguments
-    add_common_arguments(parser, include_args=['verbose', 'token', 'team', 'machine'])
+    # Note: --version is only available at root level (rediacc --version)
+    # Add common arguments (standard order: token, team, machine, verbose)
+    add_common_arguments(parser, include_args=['token', 'team', 'machine', 'verbose'])
     
     # Add repo separately since it has different requirements
     parser.add_argument('--repo', help='Target repository name (optional - if not specified, connects to machine only)')
     parser.add_argument('--container', help='Container name to connect to directly (requires --repo)')
     parser.add_argument('--command', help='Command to execute (interactive shell if not specified)')
-    parser.add_argument('--dev', action='store_true', help='Development mode - relaxes SSH host key checking')
-    
+
     args = parser.parse_args()
     
     setup_logging(verbose=args.verbose)
@@ -309,4 +327,4 @@ def main():
         shutdown_telemetry()
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
